@@ -21,7 +21,6 @@
 #include "fileindexeradaptor.h"
 #include "indexscheduler.h"
 #include "fileindexerconfig.h"
-#include "filewatchserviceinterface.h"
 #include "util.h"
 
 #include <KDebug>
@@ -34,8 +33,8 @@
 #include <Soprano/Model>
 #include <Soprano/Node>
 
-Nepomuk2::FileIndexer::FileIndexer( QObject* parent, const QList<QVariant>& )
-    : Service( parent )
+Nepomuk2::FileIndexer::FileIndexer()
+    : Service2()
 {
     // Create the configuration instance singleton (for thread-safety)
     // ==============================================================
@@ -45,13 +44,6 @@ Nepomuk2::FileIndexer::FileIndexer( QObject* parent, const QList<QVariant>& )
     // ==============================================================
     m_indexScheduler = new IndexScheduler(this);
 
-    // update the watches if the config changes
-    connect( FileIndexerConfig::self(), SIGNAL( configChanged() ),
-             this, SLOT( updateWatches() ) );
-
-    // export on dbus
-    ( void )new FileIndexerAdaptor( this );
-
     // setup status connections
     connect( m_indexScheduler, SIGNAL(statusStringChanged()),
              this, SIGNAL(statusStringChanged()) );
@@ -61,12 +53,6 @@ Nepomuk2::FileIndexer::FileIndexer( QObject* parent, const QList<QVariant>& )
         m_indexScheduler->updateAll();
     }
 
-    // Creation of watches is a memory intensive process as a large number of
-    // watch file descriptors need to be created ( one for each directory )
-    // So we start it after 2 minutes in order to reduce startup time
-    // FIXME: Add the watches in the file watcher
-    QTimer::singleShot( 2 * 60 * 1000, this, SLOT( updateWatches() ) );
-
     // Connect some signals used in the DBus interface
     connect( this, SIGNAL( statusStringChanged() ),
              this, SIGNAL( statusChanged() ) );
@@ -74,8 +60,14 @@ Nepomuk2::FileIndexer::FileIndexer( QObject* parent, const QList<QVariant>& )
              this, SIGNAL( indexingStarted() ) );
     connect( m_indexScheduler, SIGNAL( indexingStopped() ),
              this, SIGNAL( indexingStopped() ) );
-    connect( m_indexScheduler, SIGNAL( indexingFolder(QString) ),
-             this, SIGNAL( indexingFolder(QString) ) );
+    connect( m_indexScheduler, SIGNAL(fileIndexingDone()),
+             this, SIGNAL(fileIndexingDone()) );
+    connect( m_indexScheduler, SIGNAL(basicIndexingDone()),
+             this, SLOT(slotIndexingDone()) );
+
+    connect( m_indexScheduler, SIGNAL( statusStringChanged() ),
+             this, SLOT( emitStatusMessage() ) );
+
 }
 
 
@@ -88,36 +80,27 @@ void Nepomuk2::FileIndexer::slotIndexingDone()
     FileIndexerConfig::self()->setInitialRun(false);
 }
 
-
-void Nepomuk2::FileIndexer::updateWatches()
+void Nepomuk2::FileIndexer::emitStatusMessage()
 {
-    org::kde::nepomuk::FileWatch filewatch( "org.kde.nepomuk.services.nepomukfilewatch",
-                                            "/nepomukfilewatch",
-                                            QDBusConnection::sessionBus() );
-    foreach( const QString& folder, FileIndexerConfig::self()->includeFolders() ) {
-        filewatch.watchFolder( folder );
-    }
+    QString message = m_indexScheduler->userStatusString();
+
+    emit status((int)m_indexScheduler->currentStatus(), message);
 }
 
-
-QString Nepomuk2::FileIndexer::userStatusString() const
+QString Nepomuk2::FileIndexer::statusMessage() const
 {
-    return userStatusString( false );
-}
-
-
-QString Nepomuk2::FileIndexer::simpleUserStatusString() const
-{
-    return userStatusString( true );
-}
-
-
-QString Nepomuk2::FileIndexer::userStatusString( bool simple ) const
-{
-    Q_UNUSED( simple );
     return m_indexScheduler->userStatusString();
 }
 
+int Nepomuk2::FileIndexer::currentStatus() const
+{
+    return (int)m_indexScheduler->currentStatus();
+}
+
+QString Nepomuk2::FileIndexer::userStatusString() const
+{
+    return m_indexScheduler->userStatusString();
+}
 
 void Nepomuk2::FileIndexer::setSuspended( bool suspend )
 {
@@ -250,11 +233,20 @@ void Nepomuk2::FileIndexer::indexFolder(const QString& path, bool recursive, boo
 }
 
 
+int main( int argc, char **argv ) {
+    KAboutData aboutData( "nepomukfileindexer",
+                          "nepomukfileindexer",
+                          ki18n("Nepomuk File Indexer"),
+                          NEPOMUK_VERSION_STRING,
+                          ki18n("Nepomuk File Indexer"),
+                          KAboutData::License_GPL,
+                          ki18n("(c) 2008-2013, Sebastian Trüg"),
+                          KLocalizedString(),
+                          "http://nepomuk.kde.org" );
+    aboutData.addAuthor(ki18n("Sebastian Trüg"),ki18n("Developer"), "trueg@kde.org");
+    aboutData.addAuthor(ki18n("Vishesh Handa"),ki18n("Maintainer"), "me@vhanda.in");
 
-#include <kpluginfactory.h>
-#include <kpluginloader.h>
-
-NEPOMUK_EXPORT_SERVICE( Nepomuk2::FileIndexer, "nepomukfileindexer" )
-
+    Nepomuk2::Service2::initUI<Nepomuk2::FileIndexer>( argc, argv, aboutData );
+}
 #include "fileindexer.moc"
 
